@@ -7,6 +7,7 @@
 # -*- coding: utf-8 -*-
 import author_number as an
 import pypinyin as pn
+
 def fetchcode(name):
     surn_name,part=an.fun_surn_disc(name)
     if type(part)==dict:
@@ -16,11 +17,20 @@ def fetchcode(name):
             frst_letr=pron_unci[0][0].upper()
             name_code=part.get(frst_letr,frst_letr)
             auth_letr=pron_unci=pn.pinyin(surn_name,heteronym=True,style=pn.Style.FIRST_LETTER)[0][0].upper()
-        auth_code=auth_letr+name_code
+            auth_code=auth_letr+name_code
+        else:
+            numb=0
+            for firs in pron_unci[0]:
+                print(str(numb)+firs)
+                numb+=1
+            select=input('请选择读音首字母：')
+            frst_letr=pron_unci[0][select].upper()
+            name_code=part.get(frst_letr,frst_letr)
+            auth_letr=pron_unci=pn.pinyin(surn_name,heteronym=True,style=pn.Style.FIRST_LETTER)[0][0].upper()
+            auth_code=auth_letr+name_code
     else:
         auth_letr=pron_unci=pn.pinyin(surn_name,heteronym=True,style=pn.Style.FIRST_LETTER)[0][0].upper()
         name_code=part
         auth_code=auth_letr+name_code
-    
     return auth_code
         
